/**
 * The React App file
 */

// React libraries
import React, { useEffect, useRef } from 'react';

// Stylings
import './App.scss';

// Application components
import {
    BryntumDemoHeader,
    BryntumSchedulerPro,
    BryntumThemeCombo
} from '@bryntum/schedulerpro-react';
import { EventHelper } from '@bryntum/schedulerpro';
import { schedulerConfig } from './AppConfig';

const App = () => {
    const schedulerPro = useRef();

    useEffect(() => {
        const
            { instance }     = schedulerPro.current,
            { filterButton } = instance.widgetMap;

        instance.on({
            paint({ firstPaint }) {
                if (firstPaint) {
                    // To have resource images in events redrawn when assignments change, do a full refresh
                    instance.assignmentStore.on({
                        add     : 'refresh',
                        remove  : 'refresh',
                        thisObj : instance
                    });

                    // Select row when clicking a resource image on an event
                    EventHelper.on({
                        element  : instance.element,
                        delegate : '.assigned img',
                        thisObj  : instance,
                        click(event) {
                            instance.selectRow({ record : event.target.dataset.resourceId });
                        }
                    });
                }
            },
            thisObj : instance
        });

        filterButton.on({
            toggle({ pressed }) {
                if (pressed) {
                    // Filter that keeps working time ticks in time axis
                    instance.timeAxis.filter(t => instance.project.calendar.isWorkingTime(t.startDate, t.endDate));
                }
                else {
                    // Restore all ticks
                    instance.timeAxis.clearFilters();
                }
            },
            thisObj : instance
        });
    }, []);

    return (
        <>
            {/* BryntumDemoHeader component is used for Bryntum example styling only and can be removed */}
            <BryntumDemoHeader
                children={<BryntumThemeCombo />}
            />
            <BryntumSchedulerPro
                ref={schedulerPro}
                {...schedulerConfig}
            />
        </>
    );
};

export default App;
